Learn R Programming

rbacon (version 4.0.0)

Bacon_runs: list the folders present in the current core directory

Description

Lists all folders located within the core's directory.

Usage

Bacon_runs(set = get("info"), coredir = set$coredir)

Value

A list of folders

Arguments

set

Detailed information of the current run, stored within this session's memory as variable info.

coredir

The directory where the Bacon runs reside. Defaults to coredir="Bacon_runs".

Author

Maarten Blaauw, J. Andres Christen

Details

The directory is either "Bacon_runs", "Cores" or a custom-named one.