Learn R Programming

rbacon (version 3.0.0)

thinner: Thin iterations.

Description

Randomly thin iterations by a given proportion, for example if autocorrelation is visible within the MCMC series.

Usage

thinner(proportion = 0.1, set = get("info"))

Value

NA

Arguments

proportion

Proportion of iterations to remove. Should be between 0 and 1. Default proportion=0.1.

set

Detailed information of the current run, stored within this session's memory as variable info.

Author

Maarten Blaauw, J. Andres Christen

Details

From all iterations, a proportion is removed with to-be-removed iterations sampled randomly among all iterations.

Examples

Run this code
# \dontshow{
  Bacon(run=FALSE, coredir=tempfile())
  thinner(.1)
  agedepth(d.res=50, age.res=50, d.by=10)
# }
if (FALSE) {
  Bacon(ask=FALSE, coredir=tempfile())
  thinner(.2)
  agedepth()
}

Run the code above in your browser using DataLab