powered by
Randomly thin iterations by a given proportion, for example if autocorrelation is visible within the MCMC series.
thinner(proportion = 0.1, set = get("info"))
NA
Proportion of iterations to remove. Should be between 0 and 1. Default proportion=0.1.
proportion=0.1
Detailed information of the current run, stored within this session's memory as variable info.
info
Maarten Blaauw, J. Andres Christen
From all iterations, a proportion is removed with to-be-removed iterations sampled randomly among all iterations.
# \dontshow{ Bacon(run=FALSE, coredir=tempfile()) thinner(.1) agedepth(d.res=50, age.res=50, d.by=10) # } if (FALSE) { Bacon(ask=FALSE, coredir=tempfile()) thinner(.2) agedepth() }
Run the code above in your browser using DataLab